@@ -3,13 +3,7 @@ __doc__ = \
     """
 The main class here is ``_ParamsIoMixin``, which adds load and dump to ``_ParamsInitMixin``.
     """
-
-__author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
-__email__ = "matteo.ferla@gmail.com"
-__date__ = "5 November 2020 A.D."
-__license__ = "MIT"
-__version__ = "1.1.3"
-__citation__ = "None."
+from .version import *
 
 ########################################################################################################################
 
@@ -74,7 +68,7 @@ class _ParamsIoMixin(_ParamsInitMixin):
         assert self.NBR_RADIUS and self.NBR_RADIUS[0], 'Undeclared NBR_RADIUS entry'
         lines = [f'NAME {self.NAME}', str(self.comments)]
         for entries in (self.IO_STRING, self.TYPE, self.AA, self.ROTAMER_AA, self.ATOM, self.ATOM_ALIAS, self.BOND,
-                        self.CUT_BOND, self.ADD_RING, self.PROPERTIES, self.VARIANT, self.METAL_BINDING_ATOMS,
+                        self.CUT_BOND, self.CHARGE, self.ADD_RING, self.PROPERTIES, self.VARIANT, self.METAL_BINDING_ATOMS,
                         self.FIRST_SIDECHAIN_ATOM, self.BACKBONE_AA, self.RAMA_PREPRO_FILENAME,
                         self.ACT_COORD_ATOMS, self.CHI,
                         self.CONNECT, self.NBR_ATOM, self.NBR_RADIUS, self.MAINCHAIN_ATOMS,
