@@ -12,13 +12,7 @@ __doc__ = \
 The main class here is ``_RDKitRenameMixin``, which adds the various atom renaming methods.
 
     """
-
-__author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
-__email__ = "matteo.ferla@gmail.com"
-__date__ = "5 November 2020 A.D."
-__license__ = "MIT"
-__version__ = "1.1.3"
-__citation__ = "None."
+from ..version import *
 
 ########################################################################################################################
 
@@ -50,6 +44,7 @@ class _RDKitRenameMixin:
 
     def _set_PDBInfo_atomname(self, atom, name, overwrite=False):
         info = atom.GetPDBResidueInfo()
+        # if has none, it is None
         if info is None:
             isHeteroAtom = not self.is_aminoacid()
             atom.SetMonomerInfo(Chem.AtomPDBResidueInfo(atomName=self.pad_name(name),
